@@ -11,6 +11,7 @@ import json
 from functools import wraps
 from typing import Any, Dict, List, Optional, Tuple, Union
 from mitosheet.code_chunks.code_chunk_utils import get_code_chunks
+from mitosheet.step_performers.dataframe_import import get_variable_with_name_from_caller
 from mitosheet.step_performers.graph_steps.plotly_express_graphs import DO_NOT_CHANGE_PAPER_BGCOLOR_DEFAULT, DO_NOT_CHANGE_PLOT_BGCOLOR_DEFAULT, DO_NOT_CHANGE_TITLE_FONT_COLOR_DEFAULT
 from numpy import bool_, number
 
@@ -18,23 +19,10 @@ import pandas as pd
 from mitosheet.mito_widget import MitoWidget, sheet
 from mitosheet.parser import parse_formula
 from mitosheet.transpiler.transpile import transpile
-from mitosheet.types import ColumnHeader, ColumnID, GraphID, MultiLevelColumnHeader
+from mitosheet.types import ColumnHeader, ColumnID, DataframeFormat, GraphID, MultiLevelColumnHeader
 from mitosheet.utils import NpEncoder, dfs_to_array_for_json, get_new_id
 
 
-def decorate_all_functions(function_decorator):
-    """
-    Helper function to decorate all function
-    calls in a class
-    """
-    def decorator(cls):
-        for name, obj in vars(cls).items():
-            if callable(obj):
-                setattr(cls, name, function_decorator(obj))
-        return cls
-    return decorator
-
-
 def check_transpiled_code_after_call(func):
     @wraps(func)
     def wrapper(*args, **kw):
@@ -90,7 +78,7 @@ def check_dataframes_equal(test_wrapper):
             # Make sure all the mitosheet functions are defined, which replaces the
             # `from mitosheet import *` code that is at the top of all
             # transpiled code 
-            **mitosheet.__dict__ 
+            **mitosheet.__dict__,
         }, 
         original_dfs
     )
@@ -98,6 +86,7 @@ def check_dataframes_equal(test_wrapper):
     # We then check that the sheet data json that is saved by the widget, which 
     # notably uses caching, does not get incorrectly cached and is written correctly
     assert test_wrapper.mito_widget.sheet_data_json == json.dumps(dfs_to_array_for_json(
+        test_wrapper.mito_widget.steps_manager.curr_step.final_defined_state, 
         set(i for i in range(len(test_wrapper.mito_widget.steps_manager.curr_step.dfs))),
         [],
         test_wrapper.mito_widget.steps_manager.curr_step.dfs,
@@ -106,7 +95,7 @@ def check_dataframes_equal(test_wrapper):
         test_wrapper.mito_widget.steps_manager.curr_step.column_spreadsheet_code,
         test_wrapper.mito_widget.steps_manager.curr_step.column_filters,
         test_wrapper.mito_widget.steps_manager.curr_step.column_ids,
-        test_wrapper.mito_widget.steps_manager.curr_step.column_format_types
+        test_wrapper.mito_widget.steps_manager.curr_step.df_formats
     ), cls=NpEncoder)
 
 
@@ -154,6 +143,10 @@ class MitoWidgetTestWrapper:
     def df_names(self):
         return self.mito_widget.steps_manager.curr_step.df_names
 
+    @property
+    def df_formats(self):
+        return self.mito_widget.steps_manager.curr_step.df_formats
+
     @property
     def column_format_types(self):
         return self.mito_widget.steps_manager.curr_step.column_format_types
@@ -437,6 +430,54 @@ class MitoWidgetTestWrapper:
             }
         )
     
+
+    @check_transpiled_code_after_call
+    def set_dataframe_format(
+            self, 
+            sheet_index: int,
+            df_format: Any,
+        ) -> bool:
+
+        
+
+        return self.mito_widget.receive_message(
+            self.mito_widget,
+            {
+                'event': 'edit_event',
+                'id': get_new_id(),
+                'type': 'set_dataframe_format_edit',
+                'step_id': get_new_id(),
+                'params': {
+                    'sheet_index': sheet_index,
+                    'df_format': df_format,
+                    
+                }
+            }
+        )
+    
+
+    # NOTE: We do not automatically check the generated code, as the variables are not defined
+    # in this context, which cases these tests to always fail. I can't think of a good way around
+    # this, so we're just gonna skip this for now
+    def dataframe_import(
+            self, 
+            df_names: List[str],
+        ) -> bool:
+
+        
+        return self.mito_widget.receive_message(
+            self.mito_widget,
+            {
+                'event': 'edit_event',
+                'id': get_new_id(),
+                'type': 'dataframe_import_edit',
+                'step_id': get_new_id(),
+                'params': {
+                    'df_names': df_names,
+                }
+            }
+        )
+    
 # AUTOGENERATED LINE: TEST (DO NOT DELETE)
 
     @check_transpiled_code_after_call
@@ -727,32 +768,6 @@ class MitoWidgetTestWrapper:
             }
         )
 
-    @check_transpiled_code_after_call
-    def change_column_format(self, sheet_index: int, column_headers: List[ColumnHeader], new_format: Dict[str, Any]) -> bool:
-
-        column_ids = []
-        for column_header in column_headers: 
-            column_id = self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(
-                sheet_index,
-                column_header
-            )
-            column_ids.append(column_id)
-
-        return self.mito_widget.receive_message(
-            self.mito_widget,
-            {
-                'event': 'edit_event',
-                'id': get_new_id(),
-                'type': 'change_column_format_edit',
-                'step_id': get_new_id(),
-                'params': {
-                    'sheet_index': sheet_index,
-                    'column_ids': column_ids,
-                    'format_type': new_format
-                }
-            }
-        )
-
     @check_transpiled_code_after_call
     def simple_import(self, file_names: List[str], delimeters: Optional[List[str]]=None, encodings: Optional[List[str]]=None, error_bad_lines: Optional[List[bool]]=None) -> bool:
         return self.mito_widget.receive_message(
@@ -1323,6 +1338,12 @@ class MitoWidgetTestWrapper:
         graph_data = self.get_graph_data(graph_id)
         return graph_data["graphParams"]["graphStyling"]
 
+    def get_dataframe_format(self, sheet_index: int) -> DataframeFormat: 
+        """
+        Returns the DataframeFormat object for a specific sheet
+        """
+        return self.mito_widget.steps_manager.curr_step.final_defined_state.df_formats[sheet_index]
+        
 
 def create_mito_wrapper(sheet_one_A_data: List[Any], sheet_two_A_data: List[Any]=None) -> MitoWidgetTestWrapper:
     """
